@@ -1,41 +1,35 @@
 /*
     This file is part of the KDE libraries
-    Copyright (C) 2008 Carlo Segato (brandon.ml@gmail.com)
-    Copyright (C) 2011 Pau Garcia i Quiles (pgquiles@elpauer.org)
+    SPDX-FileCopyrightText: 2008 Carlo Segato <brandon.ml@gmail.com>
+    SPDX-FileCopyrightText: 2011 Pau Garcia i Quiles <pgquiles@elpauer.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "kwindowinfo.h"
 #include "kwindowsystem.h"
-#include <windows.h>
-#include <stdlib.h>
 #include <QCoreApplication>
+#include <stdlib.h>
+#include <windows.h>
 
 class Q_DECL_HIDDEN KWindowInfo::Private
 {
 public:
     Private()
-        : properties(0), properties2(0)
-    {}
+        : properties(0)
+        , properties2(0)
+    {
+    }
 
-    ~Private() { }
+    ~Private()
+    {
+    }
 
     HWND win_;
     int ref;
     unsigned long properties;
     unsigned long properties2;
+
 private:
     Private(const Private &);
     void operator=(const Private &);
@@ -43,23 +37,23 @@ private:
 
 #include <QRect>
 
-KWindowInfo::KWindowInfo(WId win, unsigned long properties, unsigned long properties2) : d(new Private)
+KWindowInfo::KWindowInfo(WId win, unsigned long properties, unsigned long properties2)
+    : d(new Private)
 {
     d->ref = 1;
     d->win_ = reinterpret_cast<HWND>(win);
-    d->properties  = properties;
+    d->properties = properties;
     d->properties2 = properties2;
 }
 
 KWindowInfo::KWindowInfo()
-    : d(NULL)
+    : d(nullptr)
 {
-
 }
 
 KWindowInfo::~KWindowInfo()
 {
-    if (d != NULL) {
+    if (d != nullptr) {
         if (--d->ref == 0) {
             delete d;
         }
@@ -69,7 +63,7 @@ KWindowInfo::~KWindowInfo()
 KWindowInfo::KWindowInfo(const KWindowInfo &wininfo)
     : d(wininfo.d)
 {
-    if (d != NULL) {
+    if (d != nullptr) {
         ++d->ref;
     }
 }
@@ -77,12 +71,12 @@ KWindowInfo::KWindowInfo(const KWindowInfo &wininfo)
 KWindowInfo &KWindowInfo::operator=(const KWindowInfo &wininfo)
 {
     if (d != wininfo.d) {
-        if (d != NULL)
+        if (d != nullptr)
             if (--d->ref == 0) {
                 delete d;
             }
         d = wininfo.d;
-        if (d != NULL) {
+        if (d != nullptr) {
             ++d->ref;
         }
     }
@@ -157,7 +151,7 @@ NET::WindowType KWindowInfo::windowType(int supported_types) const
 {
     NET::WindowType wt(NET::Normal);
 
-    long windowStyle   = GetWindowLong(d->win_, GWL_STYLE);
+    long windowStyle = GetWindowLong(d->win_, GWL_STYLE);
     long windowStyleEx = GetWindowLong(d->win_, GWL_EXSTYLE);
 
     if (windowStyle & WS_POPUP && supported_types & NET::PopupMenuMask) {
@@ -233,7 +227,7 @@ QRect KWindowInfo::geometry() const
     RECT wndRect;
     memset(&wndRect, 0, sizeof(wndRect));
 
-    //fetch the geometry INCLUDING the frames
+    // fetch the geometry INCLUDING the frames
     if (GetWindowRect(d->win_, &wndRect)) {
         QRect result;
         result.setCoords(wndRect.left, wndRect.top, wndRect.right, wndRect.bottom);
@@ -248,7 +242,7 @@ QRect KWindowInfo::frameGeometry() const
     RECT wndRect;
     memset(&wndRect, 0, sizeof(wndRect));
 
-    //fetch only client area geometries ... i hope thats right
+    // fetch only client area geometries ... i hope that's right
     if (GetClientRect(d->win_, &wndRect)) {
         QRect result;
         result.setCoords(wndRect.left, wndRect.top, wndRect.right, wndRect.bottom);
@@ -281,14 +275,14 @@ WId KWindowInfo::groupLeader() const
 
 QByteArray KWindowInfo::windowClassClass() const
 {
-//    kWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
-//        << "Pass NET::WM2WindowClass to KWindowInfo";
-//    return d->info->windowClassClass();
+    //    kWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
+    //        << "Pass NET::WM2WindowClass to KWindowInfo";
+    //    return d->info->windowClassClass();
 
     // Implemented per http://tronche.com/gui/x/icccm/sec-4.html#WM_CLASS (but only 2nd and 3rd choices, -name ignored)
     char *resourcenamevar;
     resourcenamevar = getenv("RESOURCE_NAME");
-    if (resourcenamevar != NULL) {
+    if (resourcenamevar != nullptr) {
         return QByteArray(resourcenamevar);
     }
 
@@ -297,9 +291,9 @@ QByteArray KWindowInfo::windowClassClass() const
 
 QByteArray KWindowInfo::windowClassName() const
 {
-//    kWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
-//        << "Pass NET::WM2WindowClass to KWindowInfo";
-//    return d->info->windowClassName();
+    //    kWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
+    //        << "Pass NET::WM2WindowClass to KWindowInfo";
+    //    return d->info->windowClassName();
 
     // Maybe should use RealGetWindowClass instead of GetClassName? See
     // http://blogs.msdn.com/b/oldnewthing/archive/2010/12/31/10110524.aspx
